@@ -162,7 +162,7 @@ class BaseWrapper(object, metaclass=MetaWrapper):
                     Logger.debug("%s: %s" % (cls.__name__, data.self_link))
                     # add additional class specific caching (if available)
                     cache = getattr(cls, 'cache', None)
-                    if isinstance(cache, collections.Callable):
+                    if isinstance(cache, collections.abc.Callable):
                         cache(cached)
                 return cached
             else:
@@ -171,7 +171,7 @@ class BaseWrapper(object, metaclass=MetaWrapper):
         else:
             # not a LP API representation, let the specific class handle it
             fetch = getattr(cls, 'fetch', None)
-            if isinstance(fetch, collections.Callable):
+            if isinstance(fetch, collections.abc.Callable):
                 return fetch(data)
             else:
                 raise NotImplementedError("Don't know how to fetch '%s' from LP"
@@ -743,10 +743,13 @@ class Archive(BaseWrapper):
         [Note: the permission records, themselves, aren't exposed]
         '''
         if source_package_name not in self._pkg_uploaders:
-            self._pkg_uploaders[source_package_name] = sorted(set(
-                PersonTeam(permission.person_link) for permission in
-                self._lpobject.getUploadersForPackage(source_package_name=source_package_name)
-            ))
+            self._pkg_uploaders[source_package_name] = sorted(
+                set(
+                    PersonTeam(permission.person_link) for permission in
+                    self._lpobject.getUploadersForPackage(source_package_name=source_package_name)
+                ),
+                key=lambda s: s.name
+            )
         return self._pkg_uploaders[source_package_name]
 
     def getUploadersForPackageset(self, packageset, direct_permissions=False):
@@ -764,6 +767,17 @@ class Archive(BaseWrapper):
             ))
         return self._pkgset_uploaders[key]
 
+    def getMySubscriptionURL(self):
+        '''Get the "subscription URL" for the logged in user
+
+        If this is a private archive (i.e. private PPA), this returns
+        the "subscription URL" including authentication; otherwise
+        this returns None.
+        '''
+        if self.private:
+            return PersonTeam.me.getArchiveSubscriptionURL(archive=self._lpobject)
+        return None
+
 
 class SourcePackagePublishingHistory(BaseWrapper):
     '''
@@ -1294,7 +1308,8 @@ class MetaPersonTeam(MetaWrapper):
         '''
         if '_me' not in cls.__dict__:
             try:
-                cls._me = PersonTeam(Launchpad.me)
+                # We have to use me.self_link due to LP: #504297
+                cls._me = PersonTeam(Launchpad.me.self_link)
             except HTTPError as error:
                 if error.response.status == 401:
                     # Anonymous login
